aboutsummaryrefslogtreecommitdiff
path: root/infra/libkookie/nixpkgs/pkgs/development/libraries/glib/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'infra/libkookie/nixpkgs/pkgs/development/libraries/glib/default.nix')
-rw-r--r--infra/libkookie/nixpkgs/pkgs/development/libraries/glib/default.nix14
1 files changed, 7 insertions, 7 deletions
diff --git a/infra/libkookie/nixpkgs/pkgs/development/libraries/glib/default.nix b/infra/libkookie/nixpkgs/pkgs/development/libraries/glib/default.nix
index 88848deec412..3382af17c35d 100644
--- a/infra/libkookie/nixpkgs/pkgs/development/libraries/glib/default.nix
+++ b/infra/libkookie/nixpkgs/pkgs/development/libraries/glib/default.nix
@@ -1,7 +1,7 @@
{ config, stdenv, fetchurl, gettext, meson, ninja, pkgconfig, perl, python3
, libiconv, zlib, libffi, pcre, libelf, gnome3, libselinux, bash, gnum4, gtk-doc, docbook_xsl, docbook_xml_dtd_45
-# use utillinuxMinimal to avoid circular dependency (utillinux, systemd, glib)
-, utillinuxMinimal ? null
+# use util-linuxMinimal to avoid circular dependency (util-linux, systemd, glib)
+, util-linuxMinimal ? null
, buildPackages
# this is just for tests (not in the closure of any regular package)
@@ -13,7 +13,7 @@
with stdenv.lib;
-assert stdenv.isLinux -> utillinuxMinimal != null;
+assert stdenv.isLinux -> util-linuxMinimal != null;
# TODO:
# * Make it build without python
@@ -45,11 +45,11 @@ in
stdenv.mkDerivation rec {
pname = "glib";
- version = "2.64.5";
+ version = "2.66.3";
src = fetchurl {
url = "mirror://gnome/sources/glib/${stdenv.lib.versions.majorMinor version}/${pname}-${version}.tar.xz";
- sha256 = "04fczq693wivkqd2qxvvi3sncqgznsvzfiiwsll1rbayf795pgcw";
+ sha256 = "1cdmyyycw2mf5s0f5sfd59q91223s4smcqi8n2fwrccwm5ji7wvr";
};
patches = optionals stdenv.isDarwin [
@@ -94,7 +94,7 @@ stdenv.mkDerivation rec {
bash gnum4 # install glib-gettextize and m4 macros for other apps to use
] ++ optionals stdenv.isLinux [
libselinux
- utillinuxMinimal # for libmount
+ util-linuxMinimal # for libmount
] ++ optionals stdenv.isDarwin (with darwin.apple_sdk.frameworks; [
AppKit Carbon Cocoa CoreFoundation CoreServices Foundation
]);
@@ -108,7 +108,7 @@ stdenv.mkDerivation rec {
mesonFlags = [
# Avoid the need for gobject introspection binaries in PATH in cross-compiling case.
# Instead we just copy them over from the native output.
- "-Dgtk_doc=${if stdenv.hostPlatform == stdenv.buildPlatform then "true" else "false"}"
+ "-Dgtk_doc=${boolToString (stdenv.hostPlatform == stdenv.buildPlatform)}"
"-Dnls=enabled"
"-Ddevbindir=${placeholder ''dev''}/bin"
];